@@ -22,9 +22,9 @@
 #ifndef __PANGOCAIRO_WIN32_H__
 #define __PANGOCAIRO_WIN32_H__
 
-#include "pangowin32.h"
+#include <pango/pangowin32.h>
 #include "pangowin32-private.h"
-#include "pangocairo.h"
+#include <pango/pangocairo.h>
 
 G_BEGIN_DECLS
 
@@ -43,7 +43,7 @@ struct _PangoCairoWin32FontMap
   PangoRenderer *renderer;
 };
 
-GType pango_cairo_win32_font_map_get_type (void);
+GType pango_cairo_win32_font_map_get_type (void) G_GNUC_CONST;
 
 PangoFont *_pango_cairo_win32_font_new (PangoCairoWin32FontMap       *cwfontmap,
 					PangoContext                 *context,
